@@ -69,8 +69,9 @@ void LastGoWH::radioGetPlaylistReplied(QList<LastfmTrack *> tracks)
     playlistTracks = tracks;
     playListIndex = 0;
 
-    if(isPlaying == true)
-        playTrack(playListIndex);
+    if(tracks.count() > 0)
+        if(isPlaying == true)
+            playTrack(playListIndex);
 }
 
 LastGoWH::~LastGoWH()
@@ -289,6 +290,9 @@ void LastGoWH::setPlayButtonToStop()
 
 void LastGoWH::playTrack(int i)
 {
+    qDebug() << "Track Index: " + QString::number(i);
+    qDebug() << "Track Number: " + QString::number(playlistTracks.count());
+
     setPlayButtonToStop();
 
     if(playlistTracks[i]->Image == "")
@@ -308,9 +312,7 @@ void LastGoWH::playTrack(int i)
     ui->albumDataLabel->setText(playlistTracks[i]->Album);
     ui->artistDataLabel->setText(playlistTracks[i]->Creator);
     ui->progressBar->setMaximum(playlistTracks[i]->Duration.toInt());
-
-    //qDebug() << "Duration...";
-    //qDebug() << playlistTracks[playListIndex]->Duration.toInt();
+    trackDuration = playlistTracks[i]->Duration.toInt();
 
     playlist->clear();
     playlist->addMedia(QUrl(playlistTracks[i]->Location));
@@ -332,9 +334,6 @@ void LastGoWH::nextButtonClicked()
     ui->nextTrackButton->setEnabled(false);
     playListIndex += 1;
 
-    qDebug() << playListIndex;
-    qDebug() << playlistTracks.count();
-
     if(playListIndex < playlistTracks.count())
     {
         playTrack(playListIndex);
@@ -351,7 +350,6 @@ void LastGoWH::playerStateChanged(QMediaPlayer::State state)
     if(isPlaying)
         if(state == QMediaPlayer::StoppedState)
         {
-            qDebug() << "STOPPED";
             if(!isSkipping)
                 nextButtonClicked();
         }
@@ -361,14 +359,9 @@ void LastGoWH::trackPositionChanged(qint64 position)
 {
     ui->progressBar->setValue(position);
 
-
-    // Scrobble after playing 50% of the track
-    //qDebug() << "PlayListIndex: " + QString::number(playListIndex);
-    int trackDuration = playlistTracks[playListIndex]->Duration.toInt();
-
     if(!trackScrobbled)
     {
-        if(position > (trackDuration - position))
+        if(position > (trackDuration - position)) // Scrobble after playing 50% of the track
         {
             trackScrobbled = true;
             scrobblerSubmission();
@@ -446,7 +439,7 @@ void LastGoWH::scrobblerHandshake()
     Utils *u = new Utils(this);
     QString token = u->getScrobblerAuthToken(api_secret, timestamp);
 
-    ac->scrobblerHandshake("1.2.1", "tst", "1.0", username, timestamp, token, api_key, sk);
+    ac->scrobblerHandshake("1.2.1", "lgo", "0.2", username, timestamp, token, api_key, sk);
 }
 
 void LastGoWH::scrobblerPlaying()
@@ -500,12 +493,10 @@ void LastGoWH::scrobblerHandshakeReplied(QMap<QString, QString> reply)
 
 void LastGoWH::scrobblerPlayingReplied(QString reply)
 {
-    if(reply == "OK")
-        qDebug() << "OK";
+    qDebug() << "Now playing: " + reply;
 }
 
 void LastGoWH::scrobblerSubmissionReplied(QString reply)
 {
-    //qDebug() << "Scrobbling...";
-    //qDebug() << reply;
+    qDebug() << "Scrobbling: " + reply;
 }
