@@ -1,3 +1,13 @@
+/*
+ * requests.cpp -- Manage all network requests
+ *
+ * Copyright (C) 2010 Andrea Grandi
+ * Authors: Andrea Grandi <a.grandi@gmail.com>
+ *
+ * This file is part of LastGo and is published under the GNU GPLv2
+ * See the README file for more details.
+ */
+
 #include "requests.h"
 #include <QDebug>
 
@@ -27,5 +37,5 @@ void Requests::apiRequestPost(QString url, QByteArray params)
 void Requests::apiRequestReplied(QNetworkReply *reply)
 {
     QByteArray data = reply->readAll();
-    emit dataAvailable(QString(data));
+    emit dataAvailable(QString::fromUtf8(data));
 }
